# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class PermissionName(str, Enum):
    """
    PermissionName
    """

    """
    allowed enum values
    """
    ORGANIZATION_READ = 'organization_read'
    ORGANIZATION_DELETE = 'organization_delete'
    ORGANIZATION_UPDATE = 'organization_update'
    ORGANIZATION_LIST_WORKSPACES = 'organization_list_workspaces'
    ORGANIZATION_CREATE_WORKSPACE = 'organization_create_workspace'
    ORGANIZATION_LIST_GROUP_MEMBERSHIPS = 'organization_list_group_memberships'
    ORGANIZATION_CREATE_USER = 'organization_create_user'
    ORGANIZATION_INVITE_USER = 'organization_invite_user'
    ORGANIZATION_CREATE_SERVICE_ACCOUNT = 'organization_create_service_account'
    DELETE_USER = 'delete_user'
    USER_UPDATE = 'user_update'
    ORGANIZATION_ROLE_BINDING_DELETE = 'organization_role_binding_delete'
    ORGANIZATION_CREATE_ROLE_BINDING = 'organization_create_role_binding'
    ORGANIZATION_LIST_ROLE_BINDINGS = 'organization_list_role_bindings'
    ORGANIZATION_LIST_USERS = 'organization_list_users'
    ORGANIZATION_CREATE_GROUP = 'organization_create_group'
    ORGANIZATION_LIST_GROUPS = 'organization_list_groups'
    ORGANIZATION_LIST_ROLES = 'organization_list_roles'
    GROUP_LIST_ROLE_BINDINGS = 'group_list_role_bindings'
    GROUP_READ = 'group_read'
    GROUP_LIST_USERS = 'group_list_users'
    GROUP_UPDATE = 'group_update'
    GROUP_DELETE = 'group_delete'
    GROUP_CREATE_GROUP_MEMBERSHIP = 'group_create_group_membership'
    GROUP_DELETE_GROUP_MEMBERSHIP = 'group_delete_group_membership'
    USER_LIST_ROLE_BINDINGS = 'user_list_role_bindings'
    USER_REGENERATE_CREDS = 'user_regenerate_creds'
    WORKSPACE_READ = 'workspace_read'
    WORKSPACE_UPDATE = 'workspace_update'
    WORKSPACE_DELETE = 'workspace_delete'
    WORKSPACE_LIST_PROJECTS = 'workspace_list_projects'
    WORKSPACE_CREATE_PROJECT = 'workspace_create_project'
    WORKSPACE_CREATE_DATA_PLANE = 'workspace_create_data_plane'
    WORKSPACE_LIST_DATA_PLANES = 'workspace_list_data_planes'
    WORKSPACE_LIST_DATA_PLANE_ASSOCIATIONS = 'workspace_list_data_plane_associations'
    WORKSPACE_CREATE_DATA_PLANE_ASSOCIATION = 'workspace_create_data_plane_association'
    WORKSPACE_ROLE_BINDING_DELETE = 'workspace_role_binding_delete'
    WORKSPACE_CREATE_ROLE_BINDING = 'workspace_create_role_binding'
    WORKSPACE_LIST_ROLE_BINDINGS = 'workspace_list_role_bindings'
    WORKSPACE_CREATE_WEBHOOK = 'workspace_create_webhook'
    WORKSPACE_LIST_WEBHOOKS = 'workspace_list_webhooks'
    WORKSPACE_TEST_WEBHOOK = 'workspace_test_webhook'
    WORKSPACE_CREATE_CUSTOM_AGGREGATION = 'workspace_create_custom_aggregation'
    WORKSPACE_VALIDATE_CUSTOM_AGGREGATION = 'workspace_validate_custom_aggregation'
    WORKSPACE_LIST_DATASETS = 'workspace_list_datasets'
    PROJECT_READ = 'project_read'
    PROJECT_UPDATE = 'project_update'
    PROJECT_DELETE = 'project_delete'
    PROJECT_LIST_MODELS = 'project_list_models'
    PROJECT_CREATE_MODEL = 'project_create_model'
    PROJECT_LIST_CONNECTORS = 'project_list_connectors'
    PROJECT_CREATE_CONNECTOR = 'project_create_connector'
    PROJECT_LIST_DATASETS = 'project_list_datasets'
    PROJECT_LIST_JOBS = 'project_list_jobs'
    PROJECT_CREATE_JOB = 'project_create_job'
    PROJECT_CREATE_DATASET = 'project_create_dataset'
    PROJECT_CREATE_AVAILABLE_DATASET = 'project_create_available_dataset'
    PROJECT_LIST_DATA_PLANE_ASSOCIATIONS = 'project_list_data_plane_associations'
    PROJECT_ROLE_BINDING_DELETE = 'project_role_binding_delete'
    PROJECT_CREATE_ROLE_BINDING = 'project_create_role_binding'
    PROJECT_LIST_ROLE_BINDINGS = 'project_list_role_bindings'
    PROJECT_GENERATE_METRICS_SPEC = 'project_generate_metrics_spec'
    PROJECT_CREATE_MODEL_TASK = 'project_create_model_task'
    PROJECT_CREATE_MODEL_LINK_TASK = 'project_create_model_link_task'
    MODEL_READ = 'model_read'
    MODEL_UPDATE = 'model_update'
    MODEL_DELETE = 'model_delete'
    MODEL_PUT_METRIC_CONFIG = 'model_put_metric_config'
    MODEL_LIST_METRIC_VERSIONS = 'model_list_metric_versions'
    MODEL_CREATE_METRIC_VERSION = 'model_create_metric_version'
    MODEL_ADD_METRICS_FOR_VERSION = 'model_add_metrics_for_version'
    MODEL_EDIT_DASHBOARD = 'model_edit_dashboard'
    MODEL_CREATE_ALERT = 'model_create_alert'
    MODEL_LIST_ALERTS = 'model_list_alerts'
    MODEL_CREATE_ALERT_RULE = 'model_create_alert_rule'
    MODEL_LIST_ALERT_RULES = 'model_list_alert_rules'
    MODEL_QUERY_METRICS = 'model_query_metrics'
    MODEL_METRICS_SCHEDULE_UPDATE = 'model_metrics_schedule_update'
    MODEL_METRICS_SCHEDULE_DELETE = 'model_metrics_schedule_delete'
    MODEL_TASK_READ = 'model_task_read'
    MODEL_TASK_UPDATE = 'model_task_update'
    MODEL_TASK_DELETE = 'model_task_delete'
    MODEL_TASK_SYNC = 'model_task_sync'
    MODEL_TASK_PUT_STATE_CACHE = 'model_task_put_state_cache'
    MODEL_TASK_PUT_CONNECTION_INFO = 'model_task_put_connection_info'
    MODEL_TASK_GET_CONNECTION_INFO = 'model_task_get_connection_info'
    MODEL_TASK_DELETE_CONNECTION_INFO = 'model_task_delete_connection_info'
    MODEL_TASK_REGENERATE_VALIDATION_KEY = 'model_task_regenerate_validation_key'
    CONNECTOR_READ = 'connector_read'
    CONNECTOR_UPDATE = 'connector_update'
    CONNECTOR_DELETE = 'connector_delete'
    CONNECTOR_GET_SENSITIVE_FIELDS = 'connector_get_sensitive_fields'
    CONNECTOR_PUT_CHECK_RESULT = 'connector_put_check_result'
    CONNECTOR_LIST_DATASETS = 'connector_list_datasets'
    CONNECTOR_CREATE_DATASET = 'connector_create_dataset'
    CONNECTOR_LIST_AVAILABLE_DATASETS = 'connector_list_available_datasets'
    CONNECTOR_PUT_AVAILABLE_DATASETS = 'connector_put_available_datasets'
    CONNECTOR_CREATE_AVAILABLE_DATASET = 'connector_create_available_dataset'
    AVAILABLE_DATASET_READ = 'available_dataset_read'
    AVAILABLE_DATASET_PUT_SCHEMA = 'available_dataset_put_schema'
    AVAILABLE_DATASET_CREATE_DATA_RETRIEVAL = 'available_dataset_create_data_retrieval'
    AVAILABLE_DATASET_GET_DATA_RETRIEVAL = 'available_dataset_get_data_retrieval'
    AVAILABLE_DATASET_PUT_DATA_RETRIEVAL = 'available_dataset_put_data_retrieval'
    AVAILABLE_DATASET_DELETE_DATA_RETRIEVAL = 'available_dataset_delete_data_retrieval'
    DATASET_READ = 'dataset_read'
    DATASET_UPDATE = 'dataset_update'
    DATASET_PUT_SCHEMA = 'dataset_put_schema'
    DATASET_DELETE = 'dataset_delete'
    DATASET_CREATE_DATA_RETRIEVAL = 'dataset_create_data_retrieval'
    DATASET_GET_DATA_RETRIEVAL = 'dataset_get_data_retrieval'
    DATASET_PUT_DATA_RETRIEVAL = 'dataset_put_data_retrieval'
    DATASET_DELETE_DATA_RETRIEVAL = 'dataset_delete_data_retrieval'
    PROJECT_JOB_READ = 'project_job_read'
    PROJECT_JOB_UPDATE = 'project_job_update'
    PROJECT_JOB_PUT_STATE = 'project_job_put_state'
    PROJECT_JOB_READ_LOGS = 'project_job_read_logs'
    PROJECT_JOB_READ_RUNS = 'project_job_read_runs'
    PROJECT_JOB_APPEND_LOGS = 'project_job_append_logs'
    PROJECT_JOB_READ_ERRORS = 'project_job_read_errors'
    PROJECT_JOB_APPEND_ERRORS = 'project_job_append_errors'
    DATA_PLANE_DELETE = 'data_plane_delete'
    DATA_PLANE_UPDATE = 'data_plane_update'
    DATA_PLANE_READ = 'data_plane_read'
    DATA_PLANE_REGENERATE_CREDS = 'data_plane_regenerate_creds'
    DATA_PLANE_LIST_ASSOCIATIONS = 'data_plane_list_associations'
    DATA_PLANE_JOBS_DEQUEUE_NEXT = 'data_plane_jobs_dequeue_next'
    DATA_PLANE_ASSOCIATION_DELETE = 'data_plane_association_delete'
    ALERT_RULE_READ = 'alert_rule_read'
    ALERT_RULE_UPDATE = 'alert_rule_update'
    ALERT_RULE_DELETE = 'alert_rule_delete'
    MODEL_ALERT_READ = 'model_alert_read'
    WEBHOOK_READ = 'webhook_read'
    WEBHOOK_UPDATE = 'webhook_update'
    WEBHOOK_DELETE = 'webhook_delete'
    ROLE_READ = 'role_read'
    CUSTOM_AGGREGATION_READ = 'custom_aggregation_read'
    CUSTOM_AGGREGATION_PUT = 'custom_aggregation_put'
    CUSTOM_AGGREGATION_DELETE = 'custom_aggregation_delete'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PermissionName from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.task_read_response import TaskReadResponse

class TestTaskReadResponse(unittest.TestCase):
    """TaskReadResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TaskReadResponse:
        """Test TaskReadResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TaskReadResponse`
        """
        model = TaskReadResponse()
        if include_optional:
            return TaskReadResponse(
                task = arthur_client.api_bindings.models.task_response.TaskResponse(
                    id = '', 
                    name = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    rules = [
                        arthur_client.api_bindings.models.rule_response.RuleResponse(
                            id = '', 
                            name = '', 
                            type = 'KeywordRule', 
                            apply_to_prompt = True, 
                            apply_to_response = True, 
                            enabled = True, 
                            scope = 'default', 
                            created_at = 56, 
                            updated_at = 56, 
                            config = null, )
                        ], ),
                last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                scope_model_id = ''
            )
        else:
            return TaskReadResponse(
                scope_model_id = '',
        )
        """

    def testTaskReadResponse(self):
        """Test TaskReadResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from arthur_client.api_bindings.models.custom_aggregation_spec_schema_aggregate_args_inner import CustomAggregationSpecSchemaAggregateArgsInner
from arthur_client.api_bindings.models.reported_custom_aggregation import ReportedCustomAggregation
from arthur_client.api_bindings.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class CustomAggregationSpecSchema(BaseModel):
    """
    CustomAggregationSpecSchema
    """ # noqa: E501
    name: StrictStr = Field(description="Name of the custom aggregation function.")
    description: StrictStr = Field(description="Description of the custom aggregation function and what it aggregates.")
    reported_aggregations: List[ReportedCustomAggregation] = Field(description="Metadata for every aggregation the custom aggregation reports.")
    aggregate_args: List[CustomAggregationSpecSchemaAggregateArgsInner] = Field(description="List of parameters to the custom aggregation's query function.")
    sql: StrictStr = Field(description="DuckDBSQL query for the custom aggregation.")
    id: StrictStr = Field(description="Unique identifier of the custom aggregation function.")
    workspace_id: StrictStr = Field(description="Unique identifier of the custom aggregation's parent workspace.")
    version: StrictInt = Field(description="Version number of the custom aggregation function.")
    authored_by: User = Field(description="User who authored this custom aggregation.")
    created_at: datetime = Field(description="Time of aggregation creation.")
    __properties: ClassVar[List[str]] = ["name", "description", "reported_aggregations", "aggregate_args", "sql", "id", "workspace_id", "version", "authored_by", "created_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomAggregationSpecSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in reported_aggregations (list)
        _items = []
        if self.reported_aggregations:
            for _item_reported_aggregations in self.reported_aggregations:
                if _item_reported_aggregations:
                    _items.append(_item_reported_aggregations.to_dict())
            _dict['reported_aggregations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in aggregate_args (list)
        _items = []
        if self.aggregate_args:
            for _item_aggregate_args in self.aggregate_args:
                if _item_aggregate_args:
                    _items.append(_item_aggregate_args.to_dict())
            _dict['aggregate_args'] = _items
        # override the default output from pydantic by calling `to_dict()` of authored_by
        if self.authored_by:
            _dict['authored_by'] = self.authored_by.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomAggregationSpecSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "reported_aggregations": [ReportedCustomAggregation.from_dict(_item) for _item in obj["reported_aggregations"]] if obj.get("reported_aggregations") is not None else None,
            "aggregate_args": [CustomAggregationSpecSchemaAggregateArgsInner.from_dict(_item) for _item in obj["aggregate_args"]] if obj.get("aggregate_args") is not None else None,
            "sql": obj.get("sql"),
            "id": obj.get("id"),
            "workspace_id": obj.get("workspace_id"),
            "version": obj.get("version"),
            "authored_by": User.from_dict(obj["authored_by"]) if obj.get("authored_by") is not None else None,
            "created_at": obj.get("created_at")
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from arthur_client.api_bindings.models.metrics_query_result import MetricsQueryResult
from arthur_client.api_bindings.models.metrics_upload import MetricsUpload
from arthur_client.api_bindings.models.metrics_upload_result import MetricsUploadResult
from arthur_client.api_bindings.models.metrics_version import MetricsVersion
from arthur_client.api_bindings.models.metrics_versions_sort import MetricsVersionsSort
from arthur_client.api_bindings.models.post_metrics_query import PostMetricsQuery
from arthur_client.api_bindings.models.post_metrics_versions import PostMetricsVersions
from arthur_client.api_bindings.models.resource_list_metrics_version import ResourceListMetricsVersion
from arthur_client.api_bindings.models.sort_order import SortOrder

from arthur_client.api_bindings.api_client import ApiClient, RequestSerialized
from arthur_client.api_bindings.api_response import ApiResponse
from arthur_client.api_bindings.rest import RESTResponseType


class MetricsV1Api:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_model_metrics_versions(
        self,
        model_id: StrictStr,
        sort: Annotated[Optional[MetricsVersionsSort], Field(description="Override the field used for sorting the returned list. Optional.")] = None,
        order: Annotated[Optional[SortOrder], Field(description="Override the sort order used. Optional.")] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The page to return starting from 1 up to total_pages.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The number of records per page. The max is 1000.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResourceListMetricsVersion:
        """Get Metric Versions

        Get metric versions for a model. Requires model_list_metric_versions permission.

        :param model_id: (required)
        :type model_id: str
        :param sort: Override the field used for sorting the returned list. Optional.
        :type sort: MetricsVersionsSort
        :param order: Override the sort order used. Optional.
        :type order: SortOrder
        :param page: The page to return starting from 1 up to total_pages.
        :type page: int
        :param page_size: The number of records per page. The max is 1000.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_model_metrics_versions_serialize(
            model_id=model_id,
            sort=sort,
            order=order,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResourceListMetricsVersion",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_model_metrics_versions_with_http_info(
        self,
        model_id: StrictStr,
        sort: Annotated[Optional[MetricsVersionsSort], Field(description="Override the field used for sorting the returned list. Optional.")] = None,
        order: Annotated[Optional[SortOrder], Field(description="Override the sort order used. Optional.")] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The page to return starting from 1 up to total_pages.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The number of records per page. The max is 1000.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResourceListMetricsVersion]:
        """Get Metric Versions

        Get metric versions for a model. Requires model_list_metric_versions permission.

        :param model_id: (required)
        :type model_id: str
        :param sort: Override the field used for sorting the returned list. Optional.
        :type sort: MetricsVersionsSort
        :param order: Override the sort order used. Optional.
        :type order: SortOrder
        :param page: The page to return starting from 1 up to total_pages.
        :type page: int
        :param page_size: The number of records per page. The max is 1000.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_model_metrics_versions_serialize(
            model_id=model_id,
            sort=sort,
            order=order,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResourceListMetricsVersion",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_model_metrics_versions_without_preload_content(
        self,
        model_id: StrictStr,
        sort: Annotated[Optional[MetricsVersionsSort], Field(description="Override the field used for sorting the returned list. Optional.")] = None,
        order: Annotated[Optional[SortOrder], Field(description="Override the sort order used. Optional.")] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="The page to return starting from 1 up to total_pages.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The number of records per page. The max is 1000.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Metric Versions

        Get metric versions for a model. Requires model_list_metric_versions permission.

        :param model_id: (required)
        :type model_id: str
        :param sort: Override the field used for sorting the returned list. Optional.
        :type sort: MetricsVersionsSort
        :param order: Override the sort order used. Optional.
        :type order: SortOrder
        :param page: The page to return starting from 1 up to total_pages.
        :type page: int
        :param page_size: The number of records per page. The max is 1000.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_model_metrics_versions_serialize(
            model_id=model_id,
            sort=sort,
            order=order,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResourceListMetricsVersion",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_model_metrics_versions_serialize(
        self,
        model_id,
        sort,
        order,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        # process the query parameters
        if sort is not None:
            
            _query_params.append(('sort', sort.value))
            
        if order is not None:
            
            _query_params.append(('order', order.value))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2AuthorizationCode'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/models/{model_id}/metrics/versions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_model_metrics_by_version(
        self,
        model_id: StrictStr,
        metric_version_num: Annotated[StrictInt, Field(description="The version number for the metrics being uploaded. Should be an integer.")],
        metrics_upload: MetricsUpload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MetricsUploadResult:
        """Upload Metrics For Version

        Adds metrics for a model by version. This will create the version if it does not exist. Requires model_add_metrics_for_version permission.

        :param model_id: (required)
        :type model_id: str
        :param metric_version_num: The version number for the metrics being uploaded. Should be an integer. (required)
        :type metric_version_num: int
        :param metrics_upload: (required)
        :type metrics_upload: MetricsUpload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_by_version_serialize(
            model_id=model_id,
            metric_version_num=metric_version_num,
            metrics_upload=metrics_upload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsUploadResult",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_model_metrics_by_version_with_http_info(
        self,
        model_id: StrictStr,
        metric_version_num: Annotated[StrictInt, Field(description="The version number for the metrics being uploaded. Should be an integer.")],
        metrics_upload: MetricsUpload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MetricsUploadResult]:
        """Upload Metrics For Version

        Adds metrics for a model by version. This will create the version if it does not exist. Requires model_add_metrics_for_version permission.

        :param model_id: (required)
        :type model_id: str
        :param metric_version_num: The version number for the metrics being uploaded. Should be an integer. (required)
        :type metric_version_num: int
        :param metrics_upload: (required)
        :type metrics_upload: MetricsUpload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_by_version_serialize(
            model_id=model_id,
            metric_version_num=metric_version_num,
            metrics_upload=metrics_upload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsUploadResult",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_model_metrics_by_version_without_preload_content(
        self,
        model_id: StrictStr,
        metric_version_num: Annotated[StrictInt, Field(description="The version number for the metrics being uploaded. Should be an integer.")],
        metrics_upload: MetricsUpload,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload Metrics For Version

        Adds metrics for a model by version. This will create the version if it does not exist. Requires model_add_metrics_for_version permission.

        :param model_id: (required)
        :type model_id: str
        :param metric_version_num: The version number for the metrics being uploaded. Should be an integer. (required)
        :type metric_version_num: int
        :param metrics_upload: (required)
        :type metrics_upload: MetricsUpload
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_by_version_serialize(
            model_id=model_id,
            metric_version_num=metric_version_num,
            metrics_upload=metrics_upload,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsUploadResult",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_model_metrics_by_version_serialize(
        self,
        model_id,
        metric_version_num,
        metrics_upload,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        if metric_version_num is not None:
            _path_params['metric_version_num'] = metric_version_num
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if metrics_upload is not None:
            _body_params = metrics_upload


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2AuthorizationCode'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/models/{model_id}/metrics/versions/{metric_version_num}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_model_metrics_query(
        self,
        model_id: StrictStr,
        post_metrics_query: PostMetricsQuery,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MetricsQueryResult:
        """Query Model Metrics

        Queries metrics for a model. Requires model_query_metrics permission.

        :param model_id: (required)
        :type model_id: str
        :param post_metrics_query: (required)
        :type post_metrics_query: PostMetricsQuery
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_query_serialize(
            model_id=model_id,
            post_metrics_query=post_metrics_query,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsQueryResult",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '400': "BadRequestError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_model_metrics_query_with_http_info(
        self,
        model_id: StrictStr,
        post_metrics_query: PostMetricsQuery,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MetricsQueryResult]:
        """Query Model Metrics

        Queries metrics for a model. Requires model_query_metrics permission.

        :param model_id: (required)
        :type model_id: str
        :param post_metrics_query: (required)
        :type post_metrics_query: PostMetricsQuery
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_query_serialize(
            model_id=model_id,
            post_metrics_query=post_metrics_query,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsQueryResult",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '400': "BadRequestError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_model_metrics_query_without_preload_content(
        self,
        model_id: StrictStr,
        post_metrics_query: PostMetricsQuery,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Query Model Metrics

        Queries metrics for a model. Requires model_query_metrics permission.

        :param model_id: (required)
        :type model_id: str
        :param post_metrics_query: (required)
        :type post_metrics_query: PostMetricsQuery
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_query_serialize(
            model_id=model_id,
            post_metrics_query=post_metrics_query,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsQueryResult",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '400': "BadRequestError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_model_metrics_query_serialize(
        self,
        model_id,
        post_metrics_query,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if post_metrics_query is not None:
            _body_params = post_metrics_query


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2AuthorizationCode'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/models/{model_id}/metrics/query',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def post_model_metrics_version(
        self,
        model_id: StrictStr,
        post_metrics_versions: PostMetricsVersions,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> MetricsVersion:
        """Create A Metric Version

        Creates a new version for metrics to be uploaded for this model. Requires model_create_metric_version permission.

        :param model_id: (required)
        :type model_id: str
        :param post_metrics_versions: (required)
        :type post_metrics_versions: PostMetricsVersions
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_version_serialize(
            model_id=model_id,
            post_metrics_versions=post_metrics_versions,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsVersion",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def post_model_metrics_version_with_http_info(
        self,
        model_id: StrictStr,
        post_metrics_versions: PostMetricsVersions,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[MetricsVersion]:
        """Create A Metric Version

        Creates a new version for metrics to be uploaded for this model. Requires model_create_metric_version permission.

        :param model_id: (required)
        :type model_id: str
        :param post_metrics_versions: (required)
        :type post_metrics_versions: PostMetricsVersions
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_version_serialize(
            model_id=model_id,
            post_metrics_versions=post_metrics_versions,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsVersion",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def post_model_metrics_version_without_preload_content(
        self,
        model_id: StrictStr,
        post_metrics_versions: PostMetricsVersions,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create A Metric Version

        Creates a new version for metrics to be uploaded for this model. Requires model_create_metric_version permission.

        :param model_id: (required)
        :type model_id: str
        :param post_metrics_versions: (required)
        :type post_metrics_versions: PostMetricsVersions
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._post_model_metrics_version_serialize(
            model_id=model_id,
            post_metrics_versions=post_metrics_versions,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "MetricsVersion",
            '500': "InternalServerError",
            '404': "NotFoundError",
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _post_model_metrics_version_serialize(
        self,
        model_id,
        post_metrics_versions,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if model_id is not None:
            _path_params['model_id'] = model_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if post_metrics_versions is not None:
            _body_params = post_metrics_versions


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'OAuth2AuthorizationCode'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/models/{model_id}/metrics/versions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.job_spec import JobSpec

class TestJobSpec(unittest.TestCase):
    """JobSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobSpec:
        """Test JobSpec
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobSpec`
        """
        model = JobSpec()
        if include_optional:
            return JobSpec(
                job_type = 'link_model_task',
                dataset_id = '',
                available_dataset_id = '',
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                operation_id = '',
                data_filters = [
                    arthur_client.api_bindings.models.data_result_filter.DataResultFilter(
                        field_name = '', 
                        op = 'greater_than', 
                        value = null, )
                    ],
                pagination_options = arthur_client.api_bindings.models.connector_pagination_options.ConnectorPaginationOptions(
                    page = 1.0, 
                    page_size = 56, ),
                scope_model_id = '',
                connector_id = '',
                check_range_start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                check_range_end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                task_name = '',
                onboarding_identifier = '',
                initial_rules = [
                    arthur_client.api_bindings.models.new_rule_request.NewRuleRequest(
                        name = '', 
                        type = '', 
                        apply_to_prompt = True, 
                        apply_to_response = True, 
                        config = null, )
                    ],
                rules_to_enable = [
                    ''
                    ],
                rules_to_disable = [
                    ''
                    ],
                rules_to_archive = [
                    ''
                    ],
                rules_to_add = [
                    arthur_client.api_bindings.models.new_rule_request.NewRuleRequest(
                        name = '', 
                        type = '', 
                        apply_to_prompt = True, 
                        apply_to_response = True, 
                        config = null, )
                    ],
                task_id = ''
            )
        else:
            return JobSpec(
                available_dataset_id = '',
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                operation_id = '',
                data_filters = [
                    arthur_client.api_bindings.models.data_result_filter.DataResultFilter(
                        field_name = '', 
                        op = 'greater_than', 
                        value = null, )
                    ],
                pagination_options = arthur_client.api_bindings.models.connector_pagination_options.ConnectorPaginationOptions(
                    page = 1.0, 
                    page_size = 56, ),
                scope_model_id = '',
                connector_id = '',
                check_range_start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                check_range_end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                task_name = '',
                initial_rules = [
                    arthur_client.api_bindings.models.new_rule_request.NewRuleRequest(
                        name = '', 
                        type = '', 
                        apply_to_prompt = True, 
                        apply_to_response = True, 
                        config = null, )
                    ],
                task_id = '',
        )
        """

    def testJobSpec(self):
        """Test JobSpec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
